Module: Eaco::Adapters::CouchrestModel
- Defined in:
- lib/eaco/adapters/couchrest_model.rb,
lib/eaco/adapters/couchrest_model/couchdb_lucene.rb
Overview
CouchRest::Model backing store for ACLs, that naively uses property. As the ACL class is an Hash, it gets unserialized automagically by CouchRest guts.
:nocov: because there are too many moving parts here and anyway we are going to deprecate this in favour of jsonb
Defined Under Namespace
Modules: CouchDBLucene
Class Method Summary collapse
-
.included(base)
Defines the
aclproperty on the given model. -
.strategies ⇒ Object
Returns currently available collection extraction strategies.
Class Method Details
.included(base)
This method returns an undefined value.
Defines the acl property on the given model
31 32 33 34 35 |
# File 'lib/eaco/adapters/couchrest_model.rb', line 31 def self.included(base) base.instance_eval do property :acl, acl end end |
.strategies ⇒ Object
Returns currently available collection extraction strategies.
20 21 22 |
# File 'lib/eaco/adapters/couchrest_model.rb', line 20 def self.strategies {lucene: CouchDBLucene} end |