Exception: Eaco::Forbidden
Overview
Raised when an Actor attempts an unauthorized access to a controller action that deals with a protected Resource.
Method Summary
Methods inherited from Error
Constructor Details
This class inherits a constructor from Eaco::Error